PrerenderData class

Annotation to mark a route as requiring dynamic data for prerendering.

Use this when a route needs specific data to be prerendered correctly.

Example:

@Component(...)
@PrerenderData({
  'productId': 'widget-pro',
})
class ProductComponent {}

Constructors

PrerenderData(Map<String, dynamic> data)
const

Properties

data Map<String, dynamic>
The data to use during prerendering.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited